@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod
 version: 1.4.2
-id: yesod-1.4.2-67829aa7ba8c4341f8add31623e957be
-key: yesod_9jHuMsQ6BQCLASH1vVAEEA
+id: yesod-1.4.2-651c853375b2b38ef3e2acc3ecfab514
+key: yesod_7JyMmmNGKgfAe16YcyIQEw
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -21,22 +21,22 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-1.4.2
-hs-libraries: HSyesod-1.4.2-9jHuMsQ6BQCLASH1vVAEEA
+hs-libraries: HSyesod-1.4.2-7JyMmmNGKgfAe16YcyIQEw
 depends:
-    aeson-0.11.1.0-01f93b6d659087121e16b9df8deda57c
+    aeson-0.11.1.1-0413068b3d94ca1008e286bfe7fa084f
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
     blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-extra-1.1.11-c734df1add5fd1001eeb71b770cb5cb3
+    conduit-extra-1.1.11-a2feb7bf273f01f86e07dfa0c39c1b6a
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     fast-logger-2.4.1-72875ca91290e61690089a3e7f5d8466
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
-    monad-logger-0.3.18-cd8d51c949646894888975572eea97f1
+    monad-logger-0.3.18-7704b739a8ba950a4b62906c3ab56228
     safe-0.3.9-b613242f536083d5bb04920ede356aea
     semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
-    shakespeare-2.0.7-d65cfe041713246ebadd86a7511ba6cd
+    shakespeare-2.0.7-39cc4f42107716d9e8a539beb0a84dc6
     streaming-commons-0.1.15.2-092d722155f2dc7f0b2e7a0dc037f30c
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
@@ -44,14 +44,14 @@ depends:
     unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
     unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
     wai-3.2.0-61d8ab991e10dd6c5057d0dabf632d2a
-    wai-extra-3.0.14.1-5f3982898a5be41036c34bae0277136d
+    wai-extra-3.0.14.1-66e8055b51d984feb43fefdbcd17f927
     wai-logger-2.2.4.1-f24597f93ba49a0bbd4e6ed0edc7bef2
-    warp-3.2.3-e779983be81de2d2755ab5db7108dace
-    yaml-0.8.16-d3d7ff6fb3ea07062f7f4203706ad9cb
-    yesod-auth-1.4.12-4d0ca9693c853dd4d68086b010a1e6bd
-    yesod-core-1.4.19-1b35f3e0bc5edf244c8b12abed4fd6c1
-    yesod-form-1.4.6-33df701f6ce354a3ae16e9cd594ae06c
-    yesod-persistent-1.4.0.3-8395aca265c8d812b1837a7679a2306f
+    warp-3.2.3-b193a405602f21fe67837dcb996939ee
+    yaml-0.8.16-dde1f04caad6e58716b323c82d57d5b4
+    yesod-auth-1.4.12-7be9649dc74d6f1258f9690098986b59
+    yesod-core-1.4.19-42832ae56c3d48408d8da65a0e354ab2
+    yesod-form-1.4.6-e87deb06856da3fa0104c0eca2c57620
+    yesod-persistent-1.4.0.3-ca84b6eb145e15f51b714d496323d807
 haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
 haddock-html: /usr/share/doc/haskell-yesod/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
